/**
 * Copyright (c) 2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry_overlay.core;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * This class launches the stop of the Petals Registry Overlay node in a thread. It is required to stop the registry
 * node through JMX.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class StopRegistryThread extends Thread {

    private final Logger log = Logger.getLogger(RegistryOverlayNode.LOGGER_NAME);

    private final RegistryOverlayNode registryNode;

    public StopRegistryThread(final RegistryOverlayNode registryNode) {
        super("Petals Regsitry Overlay Node Stop thread");
        this.registryNode = registryNode;
        this.setUncaughtExceptionHandler(new UncaughtExceptionHandler() {
            @Override
            public void uncaughtException(Thread t, Throwable e) {
                log.log(Level.SEVERE, "Uncaught Exception in thread " + t.getName(), e);
            }
        });
    }

    @Override
    public void run() {
        if (this.registryNode.isRunning()) {
            this.registryNode.stop();
        }
        synchronized (this.registryNode) {
            // notify Main that shutdown has happened
            this.registryNode.notifyAll();
        }
    }
}
